


SFCODES(3)           IRCAM Soundfile System            SFCODES(3)



NAME
     sfcodes:

     getsfcode -searches for a specified "code"
     putsfcode -adds and deletes coded information from a sound-
     file header

SYNOPSIS
      char *getsfcode(hd,code);
            SFHEADER *hd;
            int *code;

      putsfcode(hd,data,codeptr)
           SFHEADER *hd;
           char *data;
           SFCODE *codeptr;


           # define SF_END 0

           # define sfcodes(x) (x)->sfinfo.sf_codes

           typedef struct sfcode {
             short  code;
             short  bsize;
           } SFCODE;

DESCRIPTION
     A soundfile header has two parts. The first four items are
     fixed: the magic number, the sample rate, number of chan-
     nels, and number of bytes per sample.  The functions
     getsfcode(), and putsfcode() are used to insert and read
     soundfile header information beyond these four items.

     The last item in a soundfile's header structure, sf_codes,
     is used to point to any further information beyond the fixed
     header data.  If more data has been put into the header,
     sf_codes will be the beginning of an SFCODE struct, shown
     above.  This SFCODE struct indicates what type of informa-
     tion follows, the "code", and how many bytes it occupies,
     the "bsize".  The "bsize" is the size of the added data plus
     the size of the present SFCODE which precedes that data;
     thus, "bsize" points to the next location after the end of
     the new data.  That location will be the beginning of
     another SFCODE struct.  SF_END is a special "code" for indi-
     cating the end of SFCODEs.  This "chaining" of SFCODES and
     data structures may continue to the end of the header.

     As an example, if the maximum amplitude has been put into
     the header, sf_codes will be the beginning of an SFCODE
     struct with a "code" of 1, indicating that a SFMAXAMP struct
     follows.  The "bsize" will be 40 (bytes) ( sizeof(SFCODE )=



Printed 1/31/87               IRCAM                             1






SFCODES(3)           IRCAM Soundfile System            SFCODES(3)



     4 bytes, sizeof(SFMAXAMP) = 36 bytes). After those 40 bytes,
     there will be another SFCODE struct, the "code" indicating
     what, if any, information follows.  See the manual page
     sfheader for the definitions of SF_CODE "codes" and data
     structures.

getsfcode
     getsfcode() begins searching at header item sf_codes for an
     SFCODE having a "code" which matches its argument. If it
     does not find a matching "code" in the header, getsfcode()
     returns NULL.  If it finds the "code", getsfcode() returns a
     pointer to that location, which is an SFCODE, not the data
     itself.

putsfcode
     putsfcode() inserts new data into a header.  It first
     searches through any existing SFCODEs for a matching "code".
     If putsfcode() finds a matching "code", it replaces the old
     information with its new data, making necessary adjustments
     if the "bsizes" are different.  If putsfcode() does not find
     a matching "code", it puts the new information at the end of
     any existing SFCODEs, and then appends an SFCODE struct with
     a "code" of SF_END.

EXAMPLES
     Sndpeak and sndnorm both use these subroutines.

     This short program puts a one line comment into soundfile
     headers.
     # include <stdio.h>
     # include <sys/file.h>
     # include <sys/types.h>
     # include <sys/stat.h>
     # include <local/sfheader.h>

     # define SF_COMMENT 2

     typedef struct sfcomment {
          char comment[80];
     } SFCOMMENT;

     SFCODE comment = {
          SF_COMMENT,
          sizeof(SFCOMMENT) + sizeof(SFCODE)
     };

     main(argc,argv)
          int argc;
          char argv[];
     {
          int    sfd, result = 0;
          struct stat  sfst;



Printed 1/31/87               IRCAM                             2






SFCODES(3)           IRCAM Soundfile System            SFCODES(3)



          SFHEADER  sfh;
          SFCOMMENT *remark;
          char        line[80];

          rdwropensf("/snd/you/soundfile",sfd,sfh,sfst,"test",result);
          if(result)
               exit(1);
          if(getsfcode(&sfh,SF_COMMENT) == NULL) {
               fprintf(stderr,"Type message: 80 char maximum:0);
               fgets(line,80,stdin);
               remark = (SFCOMMENT *)line;
               putsfcode(&sfh,remark,&comment);
               lseek(sfd,0,0);     /* reset pointer to top of file */
               wheader(sfd,&sfh);  /* write in new header */
          }
          else
               fprintf(stderr,"Comment already exists.0);
          exit(0);
     }

FILES
     /usr/local/lib/libsf.a
     /usr/local/src/carl/distr/src/lib/libsf/sfcodes.c

LIBS
     In order to use getsfcode() or putsfcode(), you must load
     "libsf" with it when you compile your program:
          % cc [options]  your_program  -lsf



























Printed 1/31/87               IRCAM                             3



